@@ -17,7 +17,7 @@ use Text::Abbrev();
 use Exporter ();
 our @ISA = qw{ Exporter };
 
-our $VERSION = '0.004';
+our $VERSION = '0.008';
 
 our @EXPORT_OK = qw{
     __am_or_pm
@@ -557,8 +557,8 @@ sub _fmt_on_date {
 
     $on_date[1][8]   = "The Company of the Ring reaches Hollin, 1419.\n";
     $on_date[1][13]  = "The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.\n";
-    $on_date[1][14]  = "The Company of the Ring spends the night in Moria hall 21, 1419.\n";
-    $on_date[1][15]  = "The Bridge of Khazad-dum, and the fall of Gandalf, 1419.\n";
+    $on_date[1][14]  = "The Company of the Ring spends the night in Moria Hall 21, 1419.\n";
+    $on_date[1][15]  = "The Bridge of Khazad-dum, and fall of Gandalf, 1419.\n";
     $on_date[1][17]  = "The Company of the Ring comes to Caras Galadhon at evening, 1419.\n";
     $on_date[1][23]  = "Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.\n";
     $on_date[1][25]  = "Gandalf casts down the Balrog, and passes away.\n" .
@@ -638,7 +638,7 @@ sub _fmt_on_date {
     $on_date[3][27]  = "Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.\n";
     $on_date[3][28]  = "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n";
 
-    $on_date[4][6]   = "The mallorn tree flowers in the party field, 1420.\n";
+    $on_date[4][6]   = "The mallorn tree flowers in the Party Field, 1420.\n";
     $on_date[4][8]   = "Ring bearers are honored on the Field of Cormallen, 1419.\n";
     $on_date[4][12]  = "Gandalf arrives in Hobbiton, 1418\n";
 
@@ -1369,7 +1369,7 @@ and month, and the weekday name is omitted if the holiday is part of no
 week. So (assuming times for all events):
 
  Sun 25 Ret 1419  3:00:00 PM # Ring destroyed
- Myd 1419 12:00:OO PM        # Wedding of Aragorn and Arwen
+ Myd 1419 12:00:00 PM        # Wedding of Aragorn and Arwen
 
 =item %D
 
@@ -1734,7 +1734,6 @@ Given a month number C<(1-12)>, this subroutine returns that month's
 three-letter abbreviation. If the month number is C<0> (i.e. a holiday),
 the empty string is returned. Otherwise C<undef> is returned.
 
-
 =head2 __on_date
 
  say __on_date( $month, $day ) // '';
@@ -1747,6 +1746,9 @@ range, C<undef> is returned.
 
 The actual text returned is from Appendix B of "Lord Of The Rings", and
 is copyright J. R. R. Tolkien, renewed by Christopher R. Tolkien et al.
+Specifically, I use the Houghton Mifflin trade paperback. I find no date
+of publication, but believe it to be the early 2000s because the cover
+illustrations appear to be movie tie-ins.
 
 =head2 __on_date_accented
 
@@ -1754,7 +1756,7 @@ is copyright J. R. R. Tolkien, renewed by Christopher R. Tolkien et al.
  say __on_date_accented( $month, $day ) // '';
  say __on_date( $holiday ) // '';
 
-This wrapper for L<__on_date()|/__on_date()> accents those names and
+This wrapper for L<__on_date()|/__on_date> accents those names and
 words that are accented in the text of the Lord Of The Rings. How these
 display depends on how your Perl is configured. Note that the example
 above assumes Perl 5.10 (for C<say()> and C<//>). Even without those,
@@ -1801,7 +1803,7 @@ L<http://howardhinnant.github.io/date_algorithms.html#civil_from_days>.
 
 This subroutine assumes no particular calendar, though it does assume
 the Gregorian year-length rules, which have also been adopted for the
-Shire calendar. If you feed it am honest-to-God Rata Die day (i.e. days
+Shire calendar. If you feed it an honest-to-God Rata Die day (i.e. days
 since December 31 of proleptic Gregorian year 0) you get back the
 Gregorian year and the day of that year (C<1-366>). If you feed it a
 so-called Shire Rata Die (i.e. days since 1 Yule of Shire year 0) you
@@ -1850,7 +1852,7 @@ exception is thrown naming the missing methods; otherwise it returns its
 argument.
 
 If you intend to use a class that autoloads requisite methods, that
-class will need to properly override L<can()|UNIVERSAL/can>, or provide
+class will need to properly override C<< UNIVERSAL->can() >>, or provide
 forward references to autoloaded methods.
 
 This subroutine is used internally to validate the date argument to
@@ -1988,7 +1990,9 @@ L<DateTime::Fiction::JRRTolkien::Shire|DateTime::Fiction::JRRTolkien::Shire>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Date-Tolkien-Shire-Data>,
+L<https://github.com/trwyant/perl-Date-Tolkien-Shire-Data/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1996,7 +2000,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017-2018 by Thomas R. Wyant, III
+Copyright (C) 2017-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
